require 'rest-client'
require 'json'
require_relative '../domain/client_info_base.rb'
require_relative '../domain/user.rb'
require_relative '../domain/user_base.rb'
require_relative '../domain/application_config.rb'


class UserService
    @@create_user_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users'
    @@create_update_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/me'
    @@check_email_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/email'
    @@reset_password_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/reset_password'
    @@change_password_url ='https://showoff-rails-react-production.herokuapp.com/api/v1/users/me/password'
    @@show_logged_in_user_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/me'
    @@show_user_id_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/users/'

    def self.create_user(user)
        user_with_client_info = get_user_with_client_info(user)
        create_user_payload = User.get_payload(user_with_client_info)
        return RestClient::Request.execute(method: :post, url: @@create_user_url,
            payload: create_user_payload, headers: {'Content-Type': 'application/json'})
    end

    def self.update_user(user, bearer_token)
        user_data = get_user(user)
        update_user_payload = User.get_payload(user_data)   
        return RestClient::Request.execute(method: :put, url: @@create_update_url,
            payload: update_user_payload,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.check_email(user)
        return RestClient::Request.execute(method: :get, url: @@check_email_url, 
            headers: {'Content-Type': 'application/json', params: {:email => user.email , :client_id => ApplicationConfig.get_client_id, :client_secret => ApplicationConfig.get_client_secret}})
    end

    def self.reset_password(user)
        user_with_client_info = get_user_with_client_info(user)
        reset_password_payload = User.get_payload(user_with_client_info)  
        return RestClient::Request.execute(method: :post, url: @@reset_password_url,
            payload: reset_password_payload,
            headers: {'Content-Type': 'application/json'})
    end

    def self.change_password(user, bearer_token)
        user_data = get_user(user)
        change_password_payload = User.get_payload(user_data)
        return RestClient::Request.execute(method: :post, url: @@change_password_url,
            payload: change_password_payload,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.show_logged_in_user(bearer_token)
            return RestClient::Request.execute(method: :get, url: @@show_logged_in_user_url, 
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.show_user_id(user_id, bearer_token)
        url_with_id = @@show_user_id_url + "#{user_id}"
        return RestClient::Request.execute(method: :get, url: url_with_id, 
        headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.get_user_with_client_info(user)
        user_with_client_info = ClientInfoBase.new
        user_with_client_info.client_id = ApplicationConfig.get_client_id
        user_with_client_info.client_secret = ApplicationConfig.get_client_secret
        user_with_client_info.user = user 
        return user_with_client_info
    end 
    
    def self.get_user(user)
        user_data = UserBase.new
        user_data.user = user 
        return user_data
    end 

end

