require 'rest-client'
require 'json'
require_relative '../domain/widget_base.rb'
require_relative '../domain/widget.rb'
require_relative '../domain/application_config.rb'

class WidgetService
    @@create_widget_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/widgets'
    @@update_destroy_widget_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/widgets/'
    @@list_widget_url = 'https://showoff-rails-react-production.herokuapp.com/api/v1/widgets/visible'
    

    def self.create_widget(widget, bearer_token)
        widget_data = get_widget(widget)
        create_widget_payload = Widget.get_payload(widget_data)
        return RestClient::Request.execute(method: :post, url: @@create_widget_url,
            payload: create_widget_payload,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.update_widget(widget, widget_id, bearer_token)
        update_url_with_widget_id = @@update_destroy_widget_url + "#{widget_id}"
        widget_data = get_widget(widget)
        update_widget_payload = Widget.get_payload(widget_data)
        return RestClient::Request.execute(method: :put, url: update_url_with_widget_id,
            payload: update_widget_payload,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.destroy_widget(widget_id, bearer_token)
        destroy_url_with_widget_id = @@update_destroy_widget_url + "#{widget_id}"
        return RestClient::Request.execute(method: :delete, url: destroy_url_with_widget_id,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.get_private_widgets(bearer_token)
        return RestClient::Request.execute(method: :get, url: @@create_widget_url,
            headers: {'Content-Type': 'application/json', 'Authorization': bearer_token})
    end

    def self.get_public_widgets(bearer_token)
        return RestClient::Request.execute(method: :get, url: @@list_widget_url, 
            headers: {'Content-Type': 'application/json', params: {:client_id => ApplicationConfig.get_client_id, :client_secret => ApplicationConfig.get_client_secret}, 
            'Authorization': bearer_token})
    end

    def self.get_public_widgets_with_search_term(search_term, bearer_token)
        return RestClient::Request.execute(method: :get, url: @@list_widget_url, 
            headers: {'Content-Type': 'application/json', params: {:client_id => ApplicationConfig.get_client_id, :client_secret => ApplicationConfig.get_client_secret, :term => search_term}, 
            'Authorization': bearer_token})
    end

    def self.get_widget(widget)
        widget_data = WidgetBase.new
        widget_data.widget = widget 
        return widget_data
    end 
   
end

