require 'rest-client'

require File.dirname(__FILE__) + '/services/authentication_service'
require File.dirname(__FILE__) + '/services/user_service'
require File.dirname(__FILE__) + '/services/widget_service'
require File.dirname(__FILE__) + '/services/user_widget_service'
require File.dirname(__FILE__) + '/domain/application_config'

class WidgetsApiClient

    def self.set_config(client_id, client_secret)
       ApplicationConfig.set_config(client_id, client_secret)
    end
   
   
    #Create authentication token
    def self.create_authentication_token(auth_data)
       return AuthenticationService.create_authentication(auth_data) 
    end

    #Refresh authentication token
    def self.refresh_authentication_token(auth_data, bearer_token)
        return AuthenticationService.refresh_authentication_token(auth_data, bearer_token)
    end

    #Revoke authentication token
    def self.revoke_authentication_token(auth_data, bearer_token)
        return AuthenticationService.revoke_authentication_token(auth_data, bearer_token)
    end
    

    #Create user
    def self.create_user(user_data)
        return UserService.create_user(user_data) 
    end

     #Update user
     def self.update_user(user_data, bearer_token)
        return UserService.update_user(user_data, bearer_token) 
    end

    #Check email
    def self.check_email(user_data) 
        return UserService.check_email(user_data) 
    end

     #Reset password
     def self.reset_password(user_data) 
        return UserService.reset_password(user_data) 
    end

     #Change password
     def self.change_password(user_data, bearer_token)
        return UserService.change_password(user_data, bearer_token) 
    end

     #Show logged in user
      def self.show_logged_in_user(bearer_token)
        return UserService.show_logged_in_user(bearer_token) 
    end

    #Show user id
    def self.show_user_id(user_id, bearer_token)
        return UserService.show_user_id(user_id, bearer_token) 
    end

    #Get private widgets  
    def self.get_private_widgets(bearer_token)
        return UserWidgetService.get_private_widgets(bearer_token) 
    end

    #Get private widgets with search term
    def self.get_private_widgets_with_search_term(search_term, bearer_token)
        return UserWidgetService.get_private_widgets_with_search_term(search_term, bearer_token) 
    end

    #Get widgets by user id
    def self.get_widgets_by_user_id(user_id, bearer_token)
        return UserWidgetService.get_widgets_by_user_id(user_id, bearer_token)
    end

    #Get widgets by user id with search term
    def self.get_widgets_by_user_id_with_search_term(user_id, search_term, bearer_token)
        return UserWidgetService.get_widgets_by_user_id_with_search_term(user_id, search_term, bearer_token)
    end
    
    #Create widget
    def self.create_widget(widget_data, bearer_token)
        return WidgetService.create_widget(widget_data, bearer_token)
    end

     #Update widget
     def self.update_widget(widget_data, widget_id, bearer_token)
        return WidgetService.update_widget(widget_data, widget_id, bearer_token)
    end

     #Destroy widget
     def self.destroy_widget(widget_id, bearer_token)
        return WidgetService.destroy_widget(widget_id, bearer_token)
    end

     #Get private widgets
     def self.get_private_widgets(bearer_token)
        return WidgetService.get_private_widgets(bearer_token)
    end
    
    #Get public widgets
    def self.get_public_widgets(bearer_token)
        return WidgetService.get_public_widgets(bearer_token)
    end
    
    #Get public widgets with serach term
    def self.get_public_widgets_with_search_term(search_term, bearer_token)
        return WidgetService.get_public_widgets_with_search_term(search_term, bearer_token)
    end

    #Remove after tesing
    def self.get_access_token
        return ApplicationConfig.get_access_token
    end
    
end
